@@ -762,7 +762,7 @@ namespace ROPTLIB{
 			Manifold::CheckParams();
 			for (integer i = 0; i < numofmani; i++)
 			{
-				std::cout << i << "-th manifold parameters (the number is " << powsinterval[i + 1] - powsinterval[i] << ") :" << std::endl;
+				OUTSTREAM << i << "-th manifold parameters (the number is " << powsinterval[i + 1] - powsinterval[i] << ") :" << std::endl;
 				manifolds[i]->CheckParams();
 			}
 		}
