@@ -416,7 +416,7 @@ namespace ROPTLIB{
 		dcopy_(&length, eigenvectors, &GLOBAL::IONE, VD.matrix, &GLOBAL::IONE);
 		for (integer i = 0; i < N; i++)
 		{
-			if (eigenvalues <= 0)
+			if (eigenvalues[i] <= 0)
 			{
 				OUTSTREAM << "Error: The matrix for Matrix::LogSymmetricM is not symmetric positive definite!!" << std::endl;
 				return;
